summaryrefslogtreecommitdiff
path: root/framework/source/classes/framecontainer.cxx
diff options
context:
space:
mode:
authorArmin Le Grand <alg@apache.org>2014-07-14 19:09:11 +0000
committerArmin Le Grand <alg@apache.org>2014-07-14 19:09:11 +0000
commit3c1d4742e649fe9c8aed8c2817fe3e1f3364f298 (patch)
treee0c6e02c89aa9227726c9469da1001b3e29c41df /framework/source/classes/framecontainer.cxx
parentc5c31e2aeaedbdf76e1f38d3c385e34f5ed875ca (diff)
Resync to trunk, windows non-pro buildaoo/aw080
Diffstat (limited to 'framework/source/classes/framecontainer.cxx')
-rw-r--r--framework/source/classes/framecontainer.cxx12
1 files changed, 6 insertions, 6 deletions
diff --git a/framework/source/classes/framecontainer.cxx b/framework/source/classes/framecontainer.cxx
index 7700a9976a23..5f10cc264a38 100644
--- a/framework/source/classes/framecontainer.cxx
+++ b/framework/source/classes/framecontainer.cxx
@@ -73,12 +73,12 @@ namespace framework{
@short initialize an empty container
@descr The container will be empty then - special features (e.g. the async quit mechanism) are disabled.
- @threadsafe not neccessary - its not a singleton
+ @threadsafe not necessary - its not a singleton
@modified 01.07.2002 14:42,as96863
*****************************************************************************************************************/
FrameContainer::FrameContainer()
// initialize base classes first.
// Order is neccessary for right initilization of his and OUR member ... m_aLock
: ThreadHelpBase ( &Application::GetSolarMutex() )
/*DEPRECATEME
, m_bAsyncQuit ( sal_False ) // default must be "disabled"!
@@ -91,7 +91,7 @@ FrameContainer::FrameContainer()
@short deinitialize may a filled container
@descr Special features (if the currently are running) will be dsiabled and we free all used other ressources.
- @threadsafe not neccessary - its not a singleton
+ @threadsafe not necessary - its not a singleton
@modified 01.07.2002 14:43,as96863
*****************************************************************************************************************/
FrameContainer::~FrameContainer()
@@ -139,7 +139,7 @@ void FrameContainer::append( const css::uno::Reference< css::frame::XFrame >& xF
void FrameContainer::remove( const css::uno::Reference< css::frame::XFrame >& xFrame )
{
/* SAFE { */
// write lock neccessary for follwing erase()!
WriteGuard aWriteLock( m_aLock );
TFrameIterator aSearchedItem = ::std::find( m_aContainer.begin(), m_aContainer.end(), xFrame );
@@ -244,7 +244,7 @@ sal_uInt32 FrameContainer::getCount() const
So it will be marked as deprecated and should be replaced by "getAllElements()".
@param nIndex
- a valud between 0 and (getCount()-1) to adress one container item
+ a valud between 0 and (getCount()-1) to address one container item
@return a reference to a frame inside the container, which match with given index
@@ -278,7 +278,7 @@ css::uno::Reference< css::frame::XFrame > FrameContainer::operator[]( sal_uInt32
@short returns a snapshot of all currently existing frames inside this container
@descr Should be used to replace the deprecated functions getCount()/operator[]!
- @return a list of all frame refrences inside this container
+ @return a list of all frame references inside this container
@threadsafe yes
@modified 01.07.2002 15:09,as96863
@@ -73,12 +73,12 @@ namespace framework{
FrameContainer::FrameContainer()
// initialize base classes first.
- // Order is neccessary for right initilization of his and OUR member ... m_aLock
+ // Order is necessary for right initilization of his and OUR member ... m_aLock
: ThreadHelpBase ( &Application::GetSolarMutex() )
/*DEPRECATEME
@@ -139,7 +139,7 @@ void FrameContainer::append( const css::uno::Reference< css::frame::XFrame >& xF
{
/* SAFE { */
- // write lock neccessary for follwing erase()!
+ // write lock necessary for follwing erase()!
WriteGuard aWriteLock( m_aLock );
TFrameIterator aSearchedItem = ::std::find( m_aContainer.begin(), m_aContainer.end(), xFrame );